// Copyright 2002-2015, University of Colorado Boulder

/**
 * To understand this file, you'll need a bit of up front information.  Here's the deal: The BitRock installer builder
 * requires a 'project file' that describes the details about the installer that it needs to build.  The format of
 * that file is XML.  However, since the PhET installer builder code is, as of early 2015, written in JavaScript, it's
 * much easier to define the project file in JavaScript, and then convert it to XML when any and all modifications are
 * completed.  This file is a thus a BitRock project file in JavaScript format.  Also, it's missing a few vital pieces
 * that are intended to be added before the file is written out as XML.  These missing pieces vary based on the needs
 * of the installers that are being built, and are expected to be added by other portions of the code.
 *
 * The contents of this file were originally created by taking an XML file from the previous version of the PhET
 * installer builder code (i.e. the code that was written in PHP and maintained in the Unfuddle SVN repository) and
 * reading it in using xml2js.
 *
 * TODO: I started on this, then aborted the effort, since I started thinking that this would probably be harder to
 * maintain than the XML project files, since XML is the format of all of the BitRock examples.  So, assuming that I
 * stick with the decision to use the XML files, this file should be deleted.  I am keeping it around for now to save
 * work if I change my mind again.
 *
 * @author John Blanco
 */
define( function( require ) {
  'use strict';

  // static object, no constructor
  return {
    project: {
      shortName: [ "PhET" ],
      fullName: [ "PhET" ],
      version: [ "$VERSION$" ],
      installerFilename: [ "${product_shortname}-Installer_${platform_name}.${custom_platform_exec_suffix}\r\n    " ],
      readmeFile: [ "docs/${platform_name}/readme.txt" ],
      licenseFile: [ "docs/license.txt" ],
      installationLogFile: [ "${installdir}/install_log.txt" ],
      wrapLicenseFileText: [ "1" ],
      leftImage: [ "" ],
      logoImage: [ "images/phet-logo-48x48.png" ],
      splashImage: [ "" ],
      defaultLanguage: [ "en" ],
      allowLanguageSelection: [ "0" ],
      postInstallationScript: [ "" ],
      postInstallationScriptArguments: [ "" ],
      preUninstallationScript: [ "" ],
      preUninstallationScriptArguments: [ "" ],
      allowedLanguages: [ "" ],
      cdromPlatforms: [ "" ],
      defaultInstallationMode: [ "" ],
      defaultUnixDirectoryPermissions: [ "755" ],
      defaultUnixFilePermissions: [ "644" ],
      description: [ "The PhET Website Mirror" ],
      outputDirectory: [ "${installbuilder_install_root}/output" ],
      projectSchemaVersion: [ "1.2" ],
      saveRelativePaths: [ "1" ],
      slideShowLoop: [ "1" ],
      slideShowTiming: [ "5" ],
      startMenuGroupName: [ "${product_fullname}" ],
      style: [ "standard" ],
      summary: [ "The PhET Website Mirror is an offline copy of the PhET website, containing all the simulations on the\r\n        website.\r\n    " ],
      uninstallerDirectory: [ "${installdir}" ],
      uninstallerName: [ "" ],
      validatorProgram: [ "" ],
      vendor: [ "PhET" ],
      enableRollback: [ "0" ],
      preBuildActionList: [
        {
          setInstallerVariable: [
            { $: { name: "custom_platform_exec_suffix", value: "${platform_exec_suffix}" } },
            {
              $: { name: "custom_platform_exec_suffix", value: "bin" },
              ruleList: [
                {
                  compareText: [
                    { $: { text: "${platform_name}", logic: "does_not_equal", value: "windows" } },
                    { $: { text: "${platform_name}", logic: "does_not_equal", value: "osx" } }
                  ]
                }
              ]
            }
          ]
        }
      ],
      componentList: [
        {
          component: [
            {
              name: [ "default" ],
              description: [ "Default Component" ],
              canBeEdited: [ "1" ],
              detailedDescription: [ "" ],
              selected: [ "1" ],
              show: [ "1" ],
              componentSelectionValidationActionList: [ "" ],
              desktopShortcutList: [
                {
                  fileShortcut: [
                    {
                      comment: [ "Launches local mirror of the PhET website." ],
                      filePath: [ "${installdir}/index.html" ],
                      icon: [ "${installdir}/phet-logo-48x48.png" ],
                      name: [ "PhET Simulations" ],
                      platforms: [ "windows" ],
                      runInTerminal: [ "0" ],
                      windowsIcon: [ "${installdir}/phet-icon.ico" ]
                    }
                  ]
                }
              ], folderList: [
              {
                folder: [
                  {
                    description: [ "Program Files" ],
                    destination: [ "${installdir}" ],
                    name: [ "programfiles" ],
                    platforms: [ "all" ],
                    distributionFileList: [
                      {
                        distributionDirectory: [
                          { origin: [ "$RIP_BASE_DIR$/blog" ] },
                          { origin: [ "$RIP_BASE_DIR$/en" ] },
                          { origin: [ "$RIP_BASE_DIR$/css" ] },
                          { origin: [ "$RIP_BASE_DIR$/files" ] },
                          { origin: [ "$RIP_BASE_DIR$/images" ] },
                          { origin: [ "$RIP_BASE_DIR$/js" ] },
                          { origin: [ "$RIP_BASE_DIR$/newsletters" ] },
                          { origin: [ "$RIP_BASE_DIR$/publications" ] },
                          { origin: [ "$RIP_BASE_DIR$/sims" ] },
                          { origin: [ "$RIP_BASE_DIR$/index.html" ] },
                          { origin: [ "$RIP_BASE_DIR$/version.html" ] }
                        ],
                        distributionFile: [
                          { origin: [ "image/phet-icon.ico" ] },
                          { origin: [ "images/phet-logo-48x48.png" ] }
                        ]
                      }
                    ],
                    shortcutList: [
                      {
                        shortcut: [
                          {
                            comment: [ "Uninstall" ],
                            exec: [ "${installdir}/${uninstallerName}" ],
                            icon: [ "" ],
                            name: [ "Uninstall ${product_fullname}" ],
                            path: [ "${installdir}" ],
                            platforms: [ "all" ],
                            runInTerminal: [ "0" ],
                            windowsExec: [ "${installdir}/${uninstallerName}.exe" ],
                            windowsExecArgs: [ "" ],
                            windowsIcon: [ "" ],
                            windowsPath: [ "${installdir}" ]
                          }
                        ],
                        fileShortcut: [
                          {
                            comment: [ "Launches the local mirror of the PhET website, which contains all of the PhET\r\n                                simulations.\r\n                            " ],
                            filePath: [ "${installdir}/index.html" ],
                            icon: [ "${installdir}/phet-logo-48x48.png" ],
                            name: [ "PhET Simulations" ],
                            platforms: [ "all" ],
                            runInTerminal: [ "0" ],
                            windowsIcon: [ "${installdir}/phet-icon.ico" ]
                          }
                        ]
                      }
                    ],
                    actionList: [
                      {
                        substitute: [
                          {
                            files: [ "*/*.jnlp" ], substitutionList: [
                            {
                              substitution: [
                                { pattern: [ "@@CODEBASE@@" ], value: [ "file:///${installdir}" ] }
                              ]
                            }
                          ],
                            ruleList: [
                              {
                                platformTest: [
                                  { $: { type: "windows" } }
                                ]
                              }
                            ]
                          },
                          {
                            files: [ "*/*.jnlp" ], substitutionList: [
                            {
                              substitution: [
                                { pattern: [ "@@CODEBASE@@" ], value: [ "file://${installdir}" ] }
                              ]
                            }
                          ],
                            ruleList: [
                              {
                                platformTest: [
                                  { $: { type: "linux" } }
                                ]
                              }
                            ]
                          },
                          {
                            files: [ "*/*.jnlp" ], substitutionList: [
                            {
                              substitution: [
                                { pattern: [ "@@CODEBASE@@" ], value: [ "file://${installdir}" ] }
                              ]
                            }
                          ],
                            ruleList: [
                              {
                                platformTest: [
                                  { $: { type: "osx" } }
                                ]
                              }
                            ]
                          }
                        ]
                      }
                    ]
                  },
                  {
                    description: [ "Program Files" ],
                    destination: [ "${installdir}" ],
                    name: [ "programfileslinux" ],
                    platforms: [ "linux" ]
                  },
                  {
                    description: [ "Program Files" ],
                    destination: [ "${installdir}" ],
                    name: [ "programfileswindows" ],
                    platforms: [ "windows" ],
                    distributionFileList: [
                      {
                        distributionFile: [
                          { origin: [ "data/jre-windows.exe" ] }
                        ]
                      }
                    ]
                  }
                ]
              }
            ],
              initializationActionList: [ "" ],
              postInstallationActionList: [ "" ],
              postUninstallationActionList: [ "" ],
              readyToInstallActionList: [ "" ],
              startMenuShortcutList: [
                {
                  startMenuShortcut: [
                    {
                      comment: [ "Uninstall ${product_fullname}" ],
                      name: [ "Uninstall ${product_fullname}" ],
                      runInTerminal: [ "0" ],
                      windowsExec: [ "${installdir}/uninstall.exe" ],
                      windowsExecArgs: [ "" ],
                      windowsIcon: [ "" ],
                      windowsPath: [ "${installdir}/" ]
                    }
                  ],
                  startMenuFileShortcut: [
                    {
                      comment: [ "Launches the local mirror of the PhET website, containing all the PhET simulations.\r\n                    " ],
                      filePath: [ "${installdir}/index.html" ],
                      name: [ "PhET Simulations" ],
                      runInTerminal: [ "0" ],
                      windowsIcon: [ "${installdir}/phet-icon.ico" ]
                    }
                  ]
                }
              ]
            }
          ]
        }
      ],
      fileList: [ "" ],
      finalPageActionList: [ "" ],
      initializationActionList: [ "" ],
      installationAbortedActionList: [ "" ],
      parameterList: [
        {
          directoryParameter: [
            {
              name: [ "installdir" ],
              title: [ "" ],
              description: [ "Installer.Parameter.installdir.description" ],
              explanation: [ "Installer.Parameter.installdir.explanation" ],
              value: [ "${platform_install_prefix}/${product_shortname}" ],
              default: [ "${platform_install_prefix}/${product_shortname}" ],
              allowEmptyValue: [ "0" ],
              ask: [ "yes" ],
              cliOptionName: [ "prefix" ],
              cliOptionText: [ "" ],
              mustBeWritable: [ "yes" ],
              mustExist: [ "0" ],
              width: [ "40" ]
            }
          ]
        }
      ],
      platformOptionsList: [ "" ],
      postInstallationActionList: [
        {
          createTimeStamp: [
            { variable: [ "installation_time_stamp" ], format: [ "%s" ] }
          ],
          logMessage: [
            { text: [ "installation_time_stamp value = ${installation_time_stamp}" ] }
          ],
          addTextToFile: [
            { file: [ "${installdir}/sims/phet-installation.properties" ], text: [ "install.date.epoch.seconds=${installation_time_stamp}" ] }
          ],
          substitute: [
            {
              files: [ "${installdir}/sims/*/*.html" ], substitutionList: [
              {
                substitution: [
                  { pattern: [ "@@INSTALLATION_TIMESTAMP@@" ], value: [ "${installation_time_stamp}" ] }
                ]
              }
            ]
            }
          ],
          setInstallerVariable: [
            { name: [ "java_executable" ], value: [ "none" ] }
          ],
          autodetectJava: [
            {
              validVersionList: [
                {
                  validVersion: [
                    { maxVersion: [ "" ], minVersion: [ "1.4.2" ], vendor: [ "" ] }
                  ]
                }
              ],
              showMessageOnError: [ "0" ], promptUser: [ "0" ], abortOnError: [ "0" ]
            }
          ],
          actionGroup: [
            {
              actionList: [
                {
                  logMessage: [
                    { text: [ "java_executable value = ${java_executable}" ] }
                  ]
                }
              ]
            },
            {
              actionList: [
                {
                  showQuestion: [
                    {
                      text: [ "A current version of Java does not appear to be installed on this computer. Would you like to\r\n                        install it now? (Java is necessary for running many PhET simulations.)\r\n                    " ],
                      variable: [ "install_java" ]
                    }
                  ]
                }
              ],
              ruleList: [
                {
                  compareText: [
                    { text: [ "${java_executable}" ], logic: [ "equals" ], value: [ "none" ] }
                  ], platformTest: [
                  { type: [ "windows" ] }
                ]
                }
              ]
            },
            {
              actionList: [
                {
                  logMessage: [
                    { text: [ "Installing Java on this machine." ] }
                  ],
                  runProgram: [
                    { program: [ "${installdir}/jre-windows.exe" ] }
                  ]
                }
              ],
              ruleList: [
                {
                  platformTest: [
                    { type: [ "windows" ] }
                  ],
                  compareText: [
                    { text: [ "${install_java}" ], value: [ "yes" ], logic: [ "equals" ] }
                  ]
                }
              ]
            }
          ]
        }
      ],
      postUninstallationActionList: [ "" ],
      preInstallationActionList: [ "" ],
      preUninstallationActionList: [ "" ],
      readyToInstallActionList: [ "" ],
      slideShowImageList: [ "" ],
      customLanguageFileList: [
        {
          language: [
            { code: [ "en" ], encoding: [ "iso8859-1" ], file: [ "./phet_installer_en.lng" ] }
          ]
        }
      ]
    }
  };


  /*
   // static object, no constructor
   return {
   project: {
   shortName: [ 'PhET' ],
   fullName: [ 'PhET' ],
   version: [ '$VERSION$' ],
   installerFilename: [ '${product_shortname}-Installer_${platform_name}.${custom_platform_exec_suffix}\r\n    ' ],
   readmeFile: [ 'docs/${platform_name}/readme.txt' ],
   licenseFile: [ 'docs/license.txt' ],
   installationLogFile: [ '${installdir}/install_log.txt' ],
   wrapLicenseFileText: [ '1' ],
   leftImage: [ '' ],
   logoImage: [ 'images/phet-logo-48x48.png' ],
   splashImage: [ '' ],
   defaultLanguage: [ 'en' ],
   allowLanguageSelection: [ '0' ],
   postInstallationScript: [ '' ],
   postInstallationScriptArguments: [ '' ],
   preUninstallationScript: [ '' ],
   preUninstallationScriptArguments: [ '' ],
   allowedLanguages: [ '' ],
   cdromPlatforms: [ '' ],
   defaultInstallationMode: [ '' ],
   defaultUnixDirectoryPermissions: [ '755' ],
   defaultUnixFilePermissions: [ '644' ],
   description: [ 'The PhET Website Mirror' ],
   outputDirectory: [ '${installbuilder_install_root}/output' ],
   projectSchemaVersion: [ '1.2' ],
   saveRelativePaths: [ '1' ],
   slideShowLoop: [ '1' ],
   slideShowTiming: [ '5' ],
   startMenuGroupName: [ '${product_fullname}' ],
   style: [ 'standard' ],
   summary: [ 'The PhET Website Mirror is an offline copy of the PhET website, containing all the simulations on the\r\n        website.\r\n    ' ],
   uninstallerDirectory: [ '${installdir}' ],
   uninstallerName: [ '' ],
   validatorProgram: [ '' ],
   vendor: [ 'PhET' ],
   enableRollback: [ '0' ],
   preBuildActionList: [
   [Object]
   ],
   componentList: [
   [Object]
   ],
   fileList: [ '' ],
   finalPageActionList: [ '' ],
   initializationActionList: [ '' ],
   installationAbortedActionList: [ '' ],
   parameterList: [
   [Object]
   ],
   platformOptionsList: [ '' ],
   postInstallationActionList: [
   [Object]
   ],
   postUninstallationActionList: [ '' ],
   preInstallationActionList: [ '' ],
   preUninstallationActionList: [ '' ],
   readyToInstallActionList: [ '' ],
   slideShowImageList: [ '' ],
   customLanguageFileList: [
   [Object]
   ] } }
   };
   */
} );