// Copyright 2002-2014, University of Colorado Boulder

/**
 * Various methods for manipulating the jnlp files for Java sims.
 *
 * @author Michael Kauzmann
 */
define( function( require ) {
  'use strict';

  var XMLUtils = require( 'XMLUtils' );
  var lookPretty = require( 'eyes' ).inspector();


  return {

    /**
     * Method responsible for replacing the phet website with @@CODEBASE@@
     * so that it can be replaced with the installation directory later in the program.
     * Also adds security permissions so that java sims will work locally
     *
     * @param jnlpFile file location/name
     * @param cb
     */
    changeCodeBaseAndPermissions: function( jnlpFile, cb ) {
      var jnlpXML = XMLUtils.parseXMLFile( jnlpFile );
      // This check is a lazy workaround for a few bugs found around the oddly conventioned balance-and-torque folder
      if ( !!jnlpXML ) {
        var previousCodeBase = jnlpXML.jnlp.$.codebase;
        // This check is to make sure that if there was an error in building, but we don't want to re-rip
        // We don't add too many CODEBASE keys for the install builder
        //previousCodeBase.replace('@@CODEBASE@@' , '');
        if ( previousCodeBase.indexOf( '@@CODEBASE@@' ) === -1 ) {
          var endClip = previousCodeBase.replace( "http://phet.colorado.edu", "" );
          jnlpXML.jnlp.$.codebase = '@@CODEBASE@@' + endClip;
        }
        jnlpXML.jnlp.security = [ { 'all-permissions': '' } ];


        XMLUtils.buildAndWriteXML( jnlpXML, jnlpFile, cb );
      }
    },

    handleJNLPs: function( jnlps ) {
      //winston.log('info' , 'JNLPS: ' + jnlps)

      // Iterate through jnlps and rename them from path+filename to just filename
      for ( var i = 0; i < jnlps.length; i++ ) {

        //lookPretty(jnlps[i]);
        this.changeCodeBaseAndPermissions( jnlps[ i ] );
      }

    }
  };

} );