// Copyright 2002-2015, University of Colorado Boulder


/**
 * Handles manipulation of XML objects including jnlps
 *
 * @author Michael Kauzmann
 */
define( function( require ) {
  'use strict';

  var xml2js = require( 'xml2js' );
  var winston = require( 'winston' );
  var fse = require( 'fs-extra' );

  return {

    buildAndWriteXML: function( jsObject, file, cb ) {
      var xmlBuilder = new xml2js.Builder();
      var XML = xmlBuilder.buildObject( jsObject );
      fse.writeFileSync( file, XML );
      if ( cb ) {
        cb();
      }
    },

    parseXMLFile: function( path ) {

      var data = fse.readFileSync( path, 'utf8' );

      //On Windows found a bug where there is an nonWhitespace BOM in the beginning of XML files written with fse.writeFileSync()
      //Throws an error when XML2js tries to open file;
      //TODO: not tested on other platforms, may cause bugs.
      var cleanData = data.replace( "\ufeff", "" );

      if ( cleanData === undefined ) {
        throw new Error( 'Invalid File, could not read File' );
      }

      var theResult;
      // TODO: I believe that the callback in the following is executed synchronously, but need to verify.
      xml2js.parseString( cleanData, function( err, result ) {
        if ( !err ) {
          theResult = result;
        }
        else {
          winston.log( 'error', 'Couldn\'t parse ' + path + ', error: ' + err );
        }
      } );

      if ( theResult === undefined ) {
        throw new Error( 'Invalid XML File, could not Parse' );
      }
      return theResult;
    }

  };
} );
